@@ -1,6 +1,8 @@
 package Bundle::CPAN;
 use strict;
-$VERSION = '1.85';
+use vars qw($VERSION);
+$VERSION = '1.852'; # use 3 digits to minimize confusion with the
+                    # other CPAN.pm
 
 1;
 
@@ -8,7 +10,7 @@ __END__
 
 =head1 NAME
 
-Bundle::CPAN - A bundle to play with all the other modules on CPAN
+Bundle::CPAN - Bundle to optmize the behaviour of CPAN.pm
 
 =head1 SYNOPSIS
 
@@ -18,8 +20,6 @@ Bundle::CPAN - A bundle to play with all the other modules on CPAN
 
 Digest::SHA
 
-Module::Signature
-
 File::Temp
 
 File::HomeDir
@@ -36,7 +36,7 @@ Bundle::libnet
 
 Term::ReadKey
 
-Term::ReadLine::Perl # sorry, I'm discriminating the ::Gnu module
+ILYAZ/modules/Term-ReadLine-Perl-1.0302.tar.gz
 
 YAML
 
@@ -46,6 +46,8 @@ Module::Build
 
 CPAN
 
+File::Which
+
 =head1 DESCRIPTION
 
 This bundle includes CPAN.pm as the base module.
@@ -54,8 +56,8 @@ When CPAN installs this bundle it tries immediately to enable
 Term::ReadLine so that you do not need to restart your CPAN session.
 
 In this bundle Term::ReadLine::Perl is preferred over
-Term::ReadLine::Gnu because I expect that it gives less problems on
-portability.
+Term::ReadLine::Gnu because there is no way to express I<OR> in
+dependencies.
 
 Note that all modules in this Bundle are not strict prerequisites to
 get a working CPAN.pm. CPAN.pm can work quite well without the other
